@@ -14,7 +14,7 @@ class AB_Continous_Monitoring_Monitor_Results(abobjs.AB_Base):
 
     _endpoint = "/api/v1/continuous_monitoring_monitor_results"
     _single = ".continuous_monitoring_monitor_results[0]"
-    _name = "continuous_monitoring_monitor_results"
+    _name = "continuous_monitoring_monitor_result"
 
     _file_modal = "ContinuousMonitoringMonitorResult"
     _fileable_type = "ContinuousMonitoringMonitorResult"
